@@ -53,16 +53,20 @@ fn generate_bindings(src_dir: path::PathBuf) {
         .allowlist_function("xsk_.+")
         .allowlist_function("_xsk_.+")
         .allowlist_function("perf_buffer_.+")
+        .allowlist_function("perf_event_.+")
         .allowlist_function("ring_buffer_.+")
         .allowlist_function("vdprintf")
-        .allowlist_type("bpf_.*")
-        .allowlist_type("btf_.*")
-        .allowlist_type("xdp_.*")
-        .allowlist_type("xsk_.*")
+        .allowlist_type("bpf_.+")
+        .allowlist_type("btf_.+")
+        .allowlist_type("xdp_.+")
+        .allowlist_type("xsk_.+")
+        .allowlist_type("perf_event_.+")
+        .allowlist_type("perf_sample_.+")
         .allowlist_var("BPF_.+")
         .allowlist_var("BTF_.+")
         .allowlist_var("XSK_.+")
         .allowlist_var("XDP_.+")
+        .allowlist_var("PERF_RECORD_.+")
         .parse_callbacks(Box::new(ignored_macros))
         .header("bindings.h")
         .clang_arg(format!("-I{}", src_dir.join("libbpf/include").display()))
